@@ -46,7 +46,7 @@ from semantic_release.commit_parser import (
     ScipyCommitParser,
     TagCommitParser,
 )
-from semantic_release.const import COMMIT_MESSAGE, DEFAULT_COMMIT_AUTHOR, SEMVER_REGEX
+from semantic_release.const import COMMIT_MESSAGE, DEFAULT_COMMIT_AUTHOR
 from semantic_release.errors import (
     DetachedHeadGitError,
     InvalidConfiguration,
@@ -54,15 +54,13 @@ from semantic_release.errors import (
     NotAReleaseBranch,
     ParserLoadError,
 )
+from semantic_release.globals import logger
 from semantic_release.helpers import dynamic_import
-from semantic_release.version.declaration import (
-    PatternVersionDeclaration,
-    TomlVersionDeclaration,
-    VersionDeclarationABC,
-)
+from semantic_release.version.declarations.i_version_replacer import IVersionReplacer
+from semantic_release.version.declarations.pattern import PatternVersionDeclaration
+from semantic_release.version.declarations.toml import TomlVersionDeclaration
 from semantic_release.version.translator import VersionTranslator
 
-log = logging.getLogger(__name__)
 NonEmptyString = Annotated[str, Field(..., min_length=1)]
 
 
@@ -130,8 +128,7 @@ class ChangelogEnvironmentConfig(BaseModel):
 class DefaultChangelogTemplatesConfig(BaseModel):
     changelog_file: str = "CHANGELOG.md"
     output_format: ChangelogOutputFormat = ChangelogOutputFormat.NONE
-    # TODO: Breaking Change v10, it will become True
-    mask_initial_release: bool = False
+    mask_initial_release: bool = True
 
     @model_validator(mode="after")
     def interpret_output_format(self) -> Self:
@@ -160,7 +157,7 @@ class ChangelogConfig(BaseModel):
     )
     environment: ChangelogEnvironmentConfig = ChangelogEnvironmentConfig()
     exclude_commit_patterns: Tuple[str, ...] = ()
-    mode: ChangelogMode = ChangelogMode.INIT
+    mode: ChangelogMode = ChangelogMode.UPDATE
     insertion_flag: str = ""
     template_dir: str = "templates"
 
@@ -181,7 +178,7 @@ class ChangelogConfig(BaseModel):
     @field_validator("changelog_file", mode="after")
     @classmethod
     def changelog_file_deprecation_warning(cls, val: str) -> str:
-        log.warning(
+        logger.warning(
             str.join(
                 " ",
                 [
@@ -331,7 +328,7 @@ class RemoteConfig(BaseModel):
             )
 
         if scheme == "https" and self.insecure:
-            log.warning(
+            logger.warning(
                 str.join(
                     "\n",
                     [
@@ -362,7 +359,7 @@ class RawConfig(BaseModel):
     commit_parser_options: Dict[str, Any] = {}
     logging_use_named_masks: bool = False
     major_on_zero: bool = True
-    allow_zero_version: bool = True
+    allow_zero_version: bool = False
     repo_dir: Annotated[Path, Field(validate_default=True)] = Path(".")
     remote: RemoteConfig = RemoteConfig()
     no_git_verify: bool = False
@@ -404,7 +401,7 @@ class RawConfig(BaseModel):
     @classmethod
     def tag_commit_parser_deprecation_warning(cls, val: str) -> str:
         if val == "tag":
-            log.warning(
+            logger.warning(
                 str.join(
                     " ",
                     [
@@ -420,7 +417,7 @@ class RawConfig(BaseModel):
     @classmethod
     def angular_commit_parser_deprecation_warning(cls, val: str) -> str:
         if val == "angular":
-            log.warning(
+            logger.warning(
                 str.join(
                     " ",
                     [
@@ -555,7 +552,7 @@ class RuntimeContext:
     commit_author: Actor
     commit_message: str
     changelog_excluded_commit_patterns: Tuple[Pattern[str], ...]
-    version_declarations: Tuple[VersionDeclarationABC, ...]
+    version_declarations: Tuple[IVersionReplacer, ...]
     hvcs_client: hvcs.HvcsBase
     changelog_insertion_flag: str
     changelog_mask_initial_release: bool
@@ -587,14 +584,14 @@ class RuntimeContext:
     ) -> BranchConfig:
         for group, options in choices.items():
             if regexp(options.match).match(active_branch):
-                log.info(
+                logger.info(
                     "Using group %r options, as %r matches %r",
                     group,
                     options.match,
                     active_branch,
                 )
                 return options
-            log.debug(
+            logger.debug(
                 "Rejecting group %r as %r doesn't match %r",
                 group,
                 options.match,
@@ -720,7 +717,7 @@ class RuntimeContext:
                     # TODO: add any other placeholders here
                 ),
                 # We use re.escape to ensure that the commit message is treated as a literal
-                regex_escape(raw.commit_message),
+                regex_escape(raw.commit_message.strip()),
             )
         )
         changelog_excluded_commit_patterns = (
@@ -738,51 +735,48 @@ class RuntimeContext:
 
         commit_author = Actor(*_commit_author_valid.groups())
 
-        version_declarations: list[VersionDeclarationABC] = []
-        for decl in () if raw.version_toml is None else raw.version_toml:
-            try:
-                path, search_text = decl.split(":", maxsplit=1)
-                # VersionDeclarationABC handles path existence check
-                vd = TomlVersionDeclaration(path, search_text)
-            except ValueError as exc:
-                log.exception("Invalid TOML declaration %r", decl)
-                raise InvalidConfiguration(
-                    f"Invalid TOML declaration {decl!r}"
-                ) from exc
+        version_declarations: list[IVersionReplacer] = []
 
-            version_declarations.append(vd)
-
-        for decl in () if raw.version_variables is None else raw.version_variables:
-            try:
-                path, variable = decl.split(":", maxsplit=1)
-                # VersionDeclarationABC handles path existence check
-                search_text = str.join(
-                    "",
+        try:
+            version_declarations.extend(
+                TomlVersionDeclaration.from_string_definition(definition)
+                for definition in iter(raw.version_toml or ())
+            )
+        except ValueError as err:
+            raise InvalidConfiguration(
+                str.join(
+                    "\n",
                     [
-                        # Supports optional matching quotations around variable name
-                        # Negative lookbehind to ensure we don't match part of a variable name
-                        f"""(?x)(?P<quote1>['"])?(?<![\\w.-]){variable}(?P=quote1)?""",
-                        # Supports walrus, equals sign, or colon as assignment operator ignoring whitespace separation
-                        r"\s*(:=|[:=])\s*",
-                        # Supports optional matching quotations around version number of a SEMVER pattern
-                        f"""(?P<quote2>['"])?(?P<version>{SEMVER_REGEX.pattern})(?P=quote2)?""",
+                        "Invalid 'version_toml' configuration",
+                        str(err),
                     ],
                 )
-                pd = PatternVersionDeclaration(path, search_text)
-            except ValueError as exc:
-                log.exception("Invalid variable declaration %r", decl)
-                raise InvalidConfiguration(
-                    f"Invalid variable declaration {decl!r}"
-                ) from exc
+            ) from err
 
-            version_declarations.append(pd)
+        try:
+            version_declarations.extend(
+                PatternVersionDeclaration.from_string_definition(
+                    definition, raw.tag_format
+                )
+                for definition in iter(raw.version_variables or ())
+            )
+        except ValueError as err:
+            raise InvalidConfiguration(
+                str.join(
+                    "\n",
+                    [
+                        "Invalid 'version_variables' configuration",
+                        str(err),
+                    ],
+                )
+            ) from err
 
         # Provide warnings if the token is missing
         if not raw.remote.token:
-            log.debug("hvcs token is not set")
+            logger.debug("hvcs token is not set")
 
             if not raw.remote.ignore_token_for_push:
-                log.warning("Token value is missing!")
+                logger.warning("Token value is missing!")
 
         # hvcs_client
         hvcs_client_cls = _known_hvcs[raw.remote.type]
@@ -864,11 +858,11 @@ class RuntimeContext:
         # Here we just assume the desired changelog style matches the parser name
         # as we provide templates specific to each parser type. Unfortunately if the user has
         # provided a custom parser, it would be up to the user to provide custom templates
-        # but we just assume the base template is angular
+        # but we just assume the base template is conventional
         # changelog_style = (
         #     raw.commit_parser
         #     if raw.commit_parser in _known_commit_parsers
-        #     else "angular"
+        #     else "conventional"
         # )
 
         self = cls(
@@ -892,8 +886,7 @@ class RuntimeContext:
             changelog_excluded_commit_patterns=changelog_excluded_commit_patterns,
             # TODO: change when we have other styles per parser
             # changelog_style=changelog_style,
-            # TODO: Breaking Change v10, change to conventional
-            changelog_style="angular",
+            changelog_style="conventional",
             changelog_output_format=raw.changelog.default_templates.output_format,
             prerelease=branch_config.prerelease,
             ignore_token_for_push=raw.remote.ignore_token_for_push,
